@@ -80,4 +80,10 @@ function login_alias_options_save() {
 
 }
 
+function login_alias_version() {
+
+   return '2.1';
+
+}
+
 ?>
